@@ -171,12 +171,14 @@ class FileInfo:
         "dirname",
         "name",
         "ext",
+        "modified",
         "bitrate",
         "duration",
         "description",
         "videos",
         "audios",
         "subtitles",
+        "index",
     )
 
     def get_res(self) -> tuple[int, int]:
@@ -194,7 +196,8 @@ class FileInfo:
             return self.audios[0].samplerate
         return 48000
 
-    def __init__(self, path: str, ffmpeg: FFmpeg, log: Log):
+    def __init__(self, index: int, path: str, ffmpeg: FFmpeg, log: Log):
+        self.index = index
         self.path = path
         self.abspath = os.path.abspath(path)
         self.basename = os.path.basename(path)
@@ -207,6 +210,12 @@ class FileInfo:
         self.description = None
         self.duration = ""
 
+        try:
+            stats = os.stat(path)
+            self.modified = stats.st_mtime
+        except OSError:
+            log.error(f"Could not access: {path}")
+
         _dir = os.path.dirname(ffmpeg.path)
         _ext = os.path.splitext(ffmpeg.path)[1]
         ffprobe = os.path.join(_dir, f"ffprobe{_ext}")
