@@ -7,6 +7,7 @@ from platform import system
 from shutil import move
 from urllib.parse import quote
 
+from auto_editor.output import Ensure
 from auto_editor.timeline import Timeline
 
 from .utils import indent, safe_mkdir
@@ -73,7 +74,7 @@ def speedup(speed: float) -> str:
 
 
 def premiere_xml(
-    temp: str,
+    ensure: Ensure,
     output: str,
     timeline: Timeline,
 ) -> None:
@@ -122,7 +123,7 @@ def premiere_xml(
 
         for i in range(1, tracks):
             newtrack = os.path.join(fold, f"{i}.wav")
-            move(os.path.join(temp, f"0-{i}.wav"), newtrack)
+            move(ensure.audio(timeline.inputs[0].path, 0, i), newtrack)
             pathurls.append(fix_url(newtrack))
 
     width, height = timeline.res
@@ -259,7 +260,7 @@ def premiere_xml(
                     outfile.write(speedup(clip[2] * 100))
 
                 # Linking for video blocks
-                for i in range(max(3, tracks + 1)):
+                for i in range(max(6, tracks + 1)):
                     outfile.write("\t\t\t\t\t\t<link>\n")
                     outfile.write(
                         f"\t\t\t\t\t\t\t<linkclipref>clipitem-{(i*(len(clips)))+j+1}</linkclipref>\n"
@@ -268,8 +269,8 @@ def premiere_xml(
                         outfile.write("\t\t\t\t\t\t\t<mediatype>video</mediatype>\n")
                     else:
                         outfile.write("\t\t\t\t\t\t\t<mediatype>audio</mediatype>\n")
-                    if i == 2:
-                        outfile.write("\t\t\t\t\t\t\t<trackindex>2</trackindex>\n")
+                    if 1 <= i <= 6:
+                        outfile.write(f"\t\t\t\t\t\t\t<trackindex>{i}</trackindex>\n")
                     else:
                         outfile.write("\t\t\t\t\t\t\t<trackindex>1</trackindex>\n")
                     outfile.write(f"\t\t\t\t\t\t\t<clipindex>{j+1}</clipindex>\n")
