@@ -1,10 +1,13 @@
+from __future__ import annotations
+
 import os
 import re
 from dataclasses import dataclass
-from typing import List, Tuple
+from fractions import Fraction
 
 from auto_editor.ffwrapper import FFmpeg
 from auto_editor.timeline import Timeline
+from auto_editor.utils.chunks import Chunks
 from auto_editor.utils.func import to_timecode
 from auto_editor.utils.log import Log
 
@@ -22,14 +25,14 @@ class SubtitleParser:
     def __init__(self) -> None:
         self.supported_codecs = ("ass", "webvtt", "mov_text")
 
-    def parse(self, text, fps: float, codec: str) -> None:
+    def parse(self, text, timebase: Fraction, codec: str) -> None:
 
         if codec not in self.supported_codecs:
             raise ValueError(f"codec {codec} not supported.")
 
-        self.fps = fps
+        self.timebase = timebase
         self.codec = codec
-        self.contents: List[SerialSub] = []
+        self.contents: list[SerialSub] = []
 
         if codec == "ass":
             time_code = re.compile(r"(.*)(\d+:\d+:[\d.]+)(.*)(\d+:\d+:[\d.]+)(.*)")
@@ -60,7 +63,7 @@ class SubtitleParser:
         else:
             self.footer = text[reg.span()[1] :]
 
-    def edit(self, chunks: List[Tuple[int, int, float]]) -> None:
+    def edit(self, chunks: Chunks) -> None:
         for cut in reversed(chunks):
             the_speed = cut[2]
             speed_factor = 1 if the_speed == 99999 else 1 - (1 / the_speed)
@@ -95,8 +98,8 @@ class SubtitleParser:
             file.write(self.header)
             for c in self.contents:
                 file.write(
-                    f"{c.before}{to_timecode(c.start / self.fps, self.codec)}"
-                    f"{c.middle}{to_timecode(c.end / self.fps, self.codec)}"
+                    f"{c.before}{to_timecode(c.start / self.timebase, self.codec)}"
+                    f"{c.middle}{to_timecode(c.end / self.timebase, self.codec)}"
                     f"{c.after}"
                 )
             file.write(self.footer)
@@ -113,7 +116,7 @@ class SubtitleParser:
         hours, minutes, seconds = nums.groups()
         seconds = seconds.replace(",", ".", 1)
         return round(
-            (int(hours) * 3600 + int(minutes) * 60 + float(seconds)) * self.fps
+            (int(hours) * 3600 + int(minutes) * 60 + float(seconds)) * self.timebase
         )
 
 
@@ -137,12 +140,12 @@ def cut_subtitles(
 
         if sub.codec in parser.supported_codecs:
             with open(file_path) as file:
-                parser.parse(file.read(), timeline.fps, sub.codec)
+                parser.parse(file.read(), timeline.timebase, sub.codec)
         else:
             convert_path = os.path.join(temp, f"{s}s_convert.vtt")
             ffmpeg.run(["-i", file_path, convert_path])
             with open(convert_path) as file:
-                parser.parse(file.read(), timeline.fps, "webvtt")
+                parser.parse(file.read(), timeline.timebase, "webvtt")
 
         parser.edit(chunks)
         parser.write(new_path)
