@@ -6,9 +6,8 @@ import sys
 import textwrap
 from dataclasses import dataclass
 from shutil import get_terminal_size
-from typing import Any, Callable, Iterator, Literal, Sequence, TypeVar, Union
+from typing import Any, Callable, Iterator, Literal, TypeVar, Union
 
-import auto_editor
 from auto_editor.utils.log import Log
 
 T = TypeVar("T", bound=type)
@@ -17,30 +16,27 @@ Nargs = Union[int, Literal["*"]]
 
 @dataclass
 class Required:
-    names: Sequence[str]
+    names: tuple[str, ...]
     nargs: Nargs = "*"
     type: type = str
-    choices: Sequence[str] | None = None
-    help: str = ""
-    _type: str = "required"
+    choices: tuple[str, ...] | None = None
+    metavar: str = "[file ...] [options]"
 
 
 @dataclass
 class Options:
-    names: Sequence[str]
+    names: tuple[str, ...]
     nargs: Nargs = 1
     type: type = str
     flag: bool = False
-    choices: Sequence[str] | None = None
-    pool: bool = False
+    choices: tuple[str, ...] | None = None
+    metavar: str | None = None
     help: str = ""
-    _type: str = "option"
 
 
 @dataclass
 class OptionText:
     text: str
-    _type: str
 
 
 def indent(text: str, prefix: str) -> str:
@@ -72,16 +68,46 @@ def out(text: str) -> None:
 
 
 def print_program_help(reqs: list[Required], args: list[Options | OptionText]) -> None:
-    text = ""
-    for arg in args:
+    text = f"Usage: {' '.join([req.metavar for req in reqs])}\n\nOptions:"
+
+    width = get_terminal_size().columns - 3
+    split = int(width * 0.44) + 3
+    indent = "  "
+
+    for i, arg in enumerate(args):
         if isinstance(arg, OptionText):
-            text += f"\n  {arg.text}\n" if arg._type == "text" else "\n"
+            if i == 0:
+                text += f"\n  {arg.text}"
+                indent = "    "
+            else:
+                text += f"\n\n  {arg.text}"
         else:
-            text += "  " + ", ".join(arg.names) + f": {arg.help}\n"
-    text += "\n"
-    for req in reqs:
-        text += "  " + ", ".join(req.names) + f": {req.help}\n"
-    out(text)
+            text += "\n"
+            line = f"{indent}{', '.join(reversed(arg.names))}"
+            if arg.metavar is not None:
+                line += f" {arg.metavar}"
+
+            if arg.help == "":
+                pass
+            elif len(line) < split:
+                line = textwrap.fill(
+                    arg.help,
+                    width=width,
+                    initial_indent=f"{line}{' ' * (split - len(line))}",
+                    subsequent_indent=split * " ",
+                ).replace("&", "")
+            else:
+                line += "\n"
+                line += textwrap.fill(
+                    arg.help,
+                    width=width,
+                    initial_indent=split * " ",
+                    subsequent_indent=split * " ",
+                )
+
+            text += line
+    text += "\n\n"
+    sys.stdout.write(text)
 
 
 def get_help_data() -> dict[str, dict[str, str]]:
@@ -108,7 +134,7 @@ def to_key(op: Options | Required) -> str:
 
 
 def print_option_help(program_name: str, ns_obj: T, option: Options) -> None:
-    text = f"  {', '.join(option.names)}\n\n"
+    text = f"  {', '.join(option.names)} {'' if option.metavar is None else option.metavar}\n\n"
 
     bar_len = 11
     if option.flag:
@@ -120,10 +146,6 @@ def print_option_help(program_name: str, ns_obj: T, option: Options) -> None:
             bar_len = len(_add)
             text += _add
 
-        _add = f"    type: {option.type.__name__}\n"
-        bar_len = len(_add)
-        text += _add
-
         default: str | None = None
         try:
             default = getattr(ns_obj, to_key(option))
@@ -192,10 +214,7 @@ class ArgumentParser:
         self.requireds.append(Required(args, **kwargs))
 
     def add_text(self, text: str) -> None:
-        self.args.append(OptionText(text, "text"))
-
-    def add_blank(self) -> None:
-        self.args.append(OptionText("", "blank"))
+        self.args.append(OptionText(text))
 
     def parse_args(
         self,
@@ -207,10 +226,6 @@ class ArgumentParser:
             out(get_help_data()[self.program_name]["_"])
             sys.exit()
 
-        if len(sys_args) == 1 and sys_args[0] in ("-v", "-V"):
-            sys.stdout.write(f"{auto_editor.version} ({auto_editor.__version__})\n")
-            sys.exit()
-
         if macros is not None:
             _macros = [(x[0].union(map(to_underscore, x[0])), x[1]) for x in macros]
             for old_options, new in _macros:
@@ -232,7 +247,7 @@ class ArgumentParser:
         builtin_help = Options(
             ("--help", "-h"),
             flag=True,
-            help="Show info about this program or option then exit.",
+            help="Show info about this program or option then exit",
         )
         options.append(builtin_help)
         args.append(builtin_help)
@@ -244,8 +259,6 @@ class ArgumentParser:
         req_list_name = requireds[0].names[0]
         setting_req_list = requireds[0].nargs != 1
 
-        option_list: Any = []
-        op_key: str = ""
         oplist_name: str | None = None
         oplist_coerce: Callable[[str], str] = str
 
@@ -255,10 +268,12 @@ class ArgumentParser:
             option = get_option(arg, options)
 
             if option is None:
-                if oplist_name == "pool":
-                    option_list.append((op_key, arg))
-                elif oplist_name is not None:
-                    option_list.append(oplist_coerce(arg))
+                if oplist_name is not None:
+                    try:
+                        val = oplist_coerce(arg)
+                        ns.__setattr__(oplist_name, getattr(ns, oplist_name) + [val])
+                    except (TypeError, ValueError) as e:
+                        Log().error(e)
                 elif requireds and not arg.startswith("--"):
                     if requireds[0].nargs == 1:
                         ns.__setattr__(req_list_name, parse_value(requireds[0], arg))
@@ -280,15 +295,11 @@ class ArgumentParser:
                         )
                     Log().error(f"Unknown {label}: {arg}")
             else:
-                if oplist_name is not None and oplist_name != "pool":
-                    ns.__setattr__(oplist_name, option_list)
-
-                if not option.pool:
+                if option.nargs != "*":
                     if option in used_options:
                         Log().error(f"Cannot repeat option {option.names[0]} twice.")
                     used_options.append(option)
 
-                option_list = []
                 oplist_name = None
                 oplist_coerce = option.type
 
@@ -299,25 +310,15 @@ class ArgumentParser:
                     print_option_help(program_name, ns_obj, option)
                     sys.exit()
 
-                if option.nargs != 1:
-                    if option.pool:
-                        oplist_name = "pool"
-                        op_key = key
-                        ns.pool.append((key, next_arg))
-                    else:
-                        oplist_name = key
-                        ns.__setattr__(oplist_name, parse_value(option, next_arg))
-                elif option.flag:
+                if option.flag:
                     ns.__setattr__(key, True)
-                else:
+                elif option.nargs == 1:
                     ns.__setattr__(key, parse_value(option, next_arg))
                     i += 1
-            i += 1
+                else:
+                    oplist_name = key
 
-        if oplist_name == "pool":
-            ns.pool += option_list
-        elif oplist_name is not None:
-            ns.__setattr__(oplist_name, option_list)
+            i += 1
 
         if setting_req_list:
             ns.__setattr__(req_list_name, req_list)
